typedef struct v2Node {
	unsigned char name[36];
	unsigned char domain[24];
	unsigned int zone;
	unsigned int net;
	unsigned int node;
	unsigned int point;
} V2NODE;

/* NEW!! */
typedef struct Node {
	unsigned char name[36];
	unsigned char email[80];
	unsigned int zone;
	unsigned int net;
	unsigned int node;
	unsigned int point;
	unsigned char domain[24];
} NODE;

/*
WHEN CONVERTING TO NEW FORMATS,
CREATE CONVERSION ROUTINES IN "V2V3" BEFORE EDITING
SEE V2V3.H FOR NOTES
*/

#define FALSE 0
#define TRUE !FALSE

#include "dos.h"
#include "dir.h"
#include "ftsc.h"

/* defined in dos.h */
#ifndef __TURBOC__
struct date {
	int   da_year;
	char  da_day;
	char  da_mon;
};
#define MAXPATH   80
#define MAXDRIVE  3
#define MAXDIR    66
#define MAXFILE   9
#define MAXEXT    5
#endif

/* FamilyNet echolist structures */
typedef union colorpair {
	unsigned char fg;
	unsigned char bg;
	int attr;
} COLORPAIR;

typedef struct colorset {
	COLORPAIR text;
	COLORPAIR tag;
	COLORPAIR addr;
} COLORSET;


/* NEW!! */
/* New Database records */
typedef struct v3echo {
	char version;
	char areatag[36];
	char ShortDesc[72];
	char Restr[72];
	NODE Msgr;
	NODE Mod[5];
	char RestFlag;    /* 0=none, 1=members only, 2=sysops only,
								4=moderator approval required, 8=Read-only,
								16=Real-names only */
	char ActiveStatus;    	/* 0 = active, 1 = unlisted, 2 = drop  */
									/* RESERVE  3 = unpublished,  4 = proposed */
	char OtherFlag;
	struct date creation;
	struct date update;
	long nodes;
	long traffic;
	char TrafficPeriod;   	/* RESERVED for monthly(0), weekly(1), daily(2) */
	char OrigNetw[36];
	char group[6];
	char distribution[72];
	char gates[72];
	char RuleFile[14];
	char key[9];				/*	UNUSED */
	char password[36];
	struct date deletion;
	char language[26];
	unsigned int warncount;
	char space[4];
	char LongDesc[1111];
} ECHO; /* v3echo (same as v2echo - substructure NODE changed */

/* Configuration Structure */

typedef struct v3Config {
	unsigned char version;     /* it's good to know what version of cfg. */
	 /* char ListKeeper[35];       /* Name of person, responder to netmail */
	 /* ADDR KeeperAddr;        /* NetAddress of system (used by mail proc) */
	NODE ListKeeper;

	/* processing options */
	unsigned char defbit;      /* default behavior of echolist
	* 1  - add new echoes (otherwise inactive)
	* 2  - send reply message
	* 4  - announce new listing
	* 8  - announce update
	* 16 - announce deletion
	* 32 - keep netmail messages
	* 64 - forward submissions
	* 128 - require passwords */

	/* permissions */
	unsigned char optionbit;   /* allowable options to submitters
	 2  - allow REPL/NOREP reply
	 4  - allow ANN/NOANN announcements
	 8  - allow update announcements
	 16 - allow moderator delete
	 32 -
	 64 - allow SUB/NOSUB submission to FidoNet/other echolist    */

	/* error handling */
	unsigned char errorbit;    /* how to handle entries with errors
	 1  - accept new entries with errors
	 2  - accept updates with errors
	 4  - log error in echolist entry (console only)
	 8  - publish error
	 16 - reply to error
	 32 - log password error in echolist entry
	 64 - */

	/* message routing */
	char replybit;             /* Hold, Crash, Direct, etc.
	 1  - private message 0x0001
	 2  - crash mail 0x0002
	 4  - kill/sent 0x0080
	 8  - Hold 0x0200
	 64 - */

	/* maintenance */
	char purgebit;             /*
	 1  - Net Moderator with notice,
	 2  - Publish but show Inactive in entry,
	 4  - Inactivate old entries; require update before listing,
	 8  - Delete from database */

	/* timings */
	unsigned int WarnPeriod;
	unsigned int PurgePeriod;  /* in days, 0 = disable */
	unsigned int UpdatePeriod; /* ECHOMOD only */
	char ruletype;
			/* 1 = Attach,    2 = Include text 		*/
	char otherbit;					/*
	 1  - Touch rule files
	 2  - Use html extension in hrefs
	 4  - Ignore MOD RUL files
	 8  - Ignore *.RUL attaches */
	char mailertype;
			/* 1 = FrontDoor, 2 = Binkleyterm, ... */

	/* paths and commands */
	char mailpath[MAXDIR];
	char rcvdpath[MAXDIR];
	char secure[MAXDIR];
	char database[MAXPATH];    /* default dir/file for database */
	char logfile[MAXPATH];
	char uplinkfile[MAXPATH];  /* default dir/file (FMLYNET.NA) if missing */
	char upl_hatchcmd[80];     /* command to hatch uplink list */
	char helpfile[MAXPATH];
	char editcmd[80];          /* RESERVED for external editor */
	char listfile[MAXPATH];    /* default dir/file if missing */
	char list_archivecmd[80];  /* command to archive list */
	char list_hatchcmd[80];    /* command to hatch list */
	unsigned char ann_areatag[36];  /* areatag for ann (using mailpath) */
	unsigned int ann_HMB;      /* HMB area # to announce areas */
		 /* bitfield options can be declared in some compilers, but since they
		 are non-standard and not portable ANSI C, I prefer to check bits
		 individually by ANDing with the value of the option. */

	/* system identification */
	char originline[65];
	char filespath[MAXDIR];
	char rulepath[MAXDIR];

	NODE OtherListKeeper;
	/* 93 bytes */
	NODE SubmitFrom;
	char AnnounceFrom[35];
	char process_name[35];		/* reserved for ECHOLIST alternate names */
	char modupd_str[35];       /* reserved for MOD UPD alternate subj */
	char query_str[35];        /* reserved for ECHO QUE alternate subj */
	char cook_str[35];         /* reserved for COOKBOOK alternate subj */
	char deletefile[MAXPATH];  /* default dir/file (FMLYNET.NO) if missing */
	unsigned int warnmax;
	char wings[1];					/* UNUSED */
	ECHO defaults;
	COLORPAIR coloring;
	NODE InternetGateway;	/* added 6/29/98 */
	char cookpath[MAXDIR];
} CFG; /* v3cfg */

/* Group database records */
typedef struct group {
	char version;
	char network[18];
	int zone;
	char ShortDesc[72];
	char LongDesc[1024];
	char Infofile[13];/* zip? */
	char Adfile[13];	/* text */
	NODE Contact[2];
	NODE ListKeeper;
	NODE Empty;
	char password[36];
	char ActiveStatus;

	struct date creation;
	struct date update;
	char OrigNetw[36];
	char abbr[6];
	char distribution[72];
	long nodes;
	char ann_areatag[36];
	char listfile[MAXPATH];
	char uplinkfile[MAXPATH];
	char wings[5];
} GROUP;

/* History log records */
typedef struct activity {
	struct date when;
	char areatag[36];
	char change[10];	/* 0 = added, 1 = updated, 2 = dropped, 3 = activated */
	char by[36];
} ACTION;

typedef struct publication {
	char reportname[80];
	char report[MAXPATH];
	char header[MAXPATH];
	char formatline[36][5];
	char hatchcommand[80];
	/* list of areas, groups to include */
	char wings[256];
} PUB;


/* OTHER VERSION'S STRUCTURES ARE IN V2V3.H */
